#
# spec file for package SDL2_ttf
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           SDL2_ttf
%define lname	libSDL2_ttf-2_0-0
Version:        2.24.0
Release:        1.1
Summary:        Simple DirectMedia Layer 2 Truetype library
License:        Zlib
Group:          Development/Libraries/X11
URL:            https://github.com/libsdl-org/SDL_ttf

#Git-Clone:	https://github.com/libsdl-org/SDL_ttf
Source:         https://github.com/libsdl-org/SDL_ttf/releases/download/release-%version/SDL2_ttf-%version.tar.gz
Source2:        https://github.com/libsdl-org/SDL_ttf/releases/download/release-%version/SDL2_ttf-%version.tar.gz.sig
Source8:        %name.keyring
BuildRequires:  SDL2-devel >= 2.24
BuildRequires:  c++_compiler
BuildRequires:  dos2unix
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(freetype2)

%description
This is a sample library that allows you to use TrueType fonts in your
SDL applications.

%package -n %lname
Summary:        Simple DirectMedia Layer 2 Truetype library
Group:          System/Libraries
Provides:       SDL2_ttf = %version

%description -n %lname
This is a sample library that allows you to use TrueType fonts in your
SDL applications.

%package devel
Summary:        Header files for the Simple DirectMedia Layer 2 Truetype library
Group:          Development/Libraries/X11
Requires:       %lname = %version
Obsoletes:      libSDL2_ttf-devel < %version-%release
Provides:       libSDL2_ttf-devel = %version-%release

%description devel
This is a sample library that allows you to use TrueType fonts in your
SDL applications.

%prep
%autosetup -p1
dos2unix *.txt

%build
%configure --disable-static
%make_build

%install
%make_install
rm -f "%buildroot/%_libdir"/*.la

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files -n %lname
%license LICENSE.txt
%_libdir/libSDL2_ttf-2*.so.*

%files devel
%doc CHANGES.txt README.txt
%_includedir/SDL2/
%_libdir/libSDL2_ttf.so
%_libdir/pkgconfig/SDL2_ttf.pc
%_libdir/cmake/

%changelog
* Thu Jan  2 2025 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.24
  * Added function ``TTF_SetFontLineSkip()``
* Sun Jan 21 2024 Jan Engelhardt <jengelh@inai.de>
- Update to relesae 2.22
  * Unspecified bug fixes
* Tue Feb  7 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.20.2
  * Build system changes only
* Mon Sep  5 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Add back Provides: SDL2_ttf = %%version to library package: the
  python bindings somewhat rely on the name to find the right
  library.
* Sat Aug 20 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.20.1
  * Build updates for non-Linux platforms
- Rename devel package to just %%name-devel, which is what most
  our packages do.
* Thu Jul  7 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.20.0
  * Added TTF_GetFontWrappedAlign() and TTF_SetFontWrappedAlign()
    to set alignment on wrapped text
  * Added functions to render using FreeType LCD algorithm:
    TTF_RenderText_LCD(), TTF_RenderUTF8_LCD(),
    TTF_RenderUNICODE_LCD(), TTF_RenderText_LCD_Wrapped(),
    TTF_RenderUTF8_LCD_Wrapped(),
    TTF_RenderUNICODE_LCD_Wrapped(), TTF_RenderGlyph_LCD(),
    TTF_RenderGlyph32_LCD().
  * Added TTF_SetFontDirection() and TTF_SetFontScriptName() for
    additional control over fonts using HarfBuzz
  * Fix memory corruption loading malformed TTF files
    [CVE-2022-27470]
- Drop baselibs.conf (no SDL2_ttf-dependent Tumbleweed packages
  themselves have baselibs).
* Wed Jan 12 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.0.18
  * Added TTF_GetFreeTypeVersion() and TTF_GetHarfBuzzVersion()
  * Added support for Signed Distance Field rendering with
    TTF_SetFontSDF() and TTF_GetFontSDF()
  * Added optional DPI-scaling of fonts, with new functions.
  * Added 32-bit character support.
  * Added functions to set direction and script when using Harfbuzz.
  * Added extended API for text measurement.
  * Added TTF_SetFontSize() to set font size dynamically.
  * Added 'Shaded' and 'Solid' text wrapped functions.
  * Added TTF_HINTING_LIGHT_SUBPIXEL for better results at small
    text sizes at a performance cost
* Fri Aug 23 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 2.0.15
  * Text rendering functions now use the alpha component of the
    text colors.
  * Added support for characters greater than 0xFFFF (e.g. emoji)
    in the UTF-8 APIs.
* Sat Oct 22 2016 aloisio@gmx.com
- Update to version 2.0.14
  * Deprecated TTF_GetFontKerningSize() which takes font glyph
    indices and added TTF_GetFontKerningSizeGlyphs() which
    takes characters
* Sun Jan 10 2016 mailaender@opensuse.org
- Update to version 2.0.13
  * Fixed bug rendering text starting with a glyph with negative starting offset
  * Fixed regression loading non-scalable fonts
  * TTF_GetFontKerningSize() gets kerning between two characters, not two glyph indices
* Thu Jan  8 2015 jengelh@inai.de
- Improve package summary and description. Drop --with-pic which
  is enabled implicitly anyway, remove redundant Requires.
* Tue Aug 13 2013 jengelh@inai.de
- Some metadata spruce-up: add current URLs, softer wildcarding
  in the files list, more robust make install call
* Tue Aug 13 2013 prusnak@opensuse.org
- created package (version 2.0.0) - based on SDL_ttf package
